@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 package Mail::DKIM;
-our $VERSION = 0.38;
+our $VERSION = 0.41;
 
 1;
 __END__
@@ -73,10 +73,20 @@ author signing policy is supposed to identify the practice of the message
 author, so you could for example reject a message from an author who claims
 they always sign their messages. See L<Mail::DKIM::Policy>.
 
+Please report bugs to the CPAN RT, or github issue tracker.
+
+https://rt.cpan.org/Public/Dist/Display.html?Name=Mail-DKIM
+
+https://github.com/fastmail/mail-dkim/issues
+
 =head1 AUTHOR
 
 Jason Long, E<lt>jlong@messiah.eduE<gt>
 
+=head1 CONTRIBUTORS
+
+Marc Bradshaw, E<lt>marc@marcbradshaw.netE<gt>
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2006-2007, 2009 by Messiah College
