@@ -111,7 +111,8 @@ is written to the referenced string or file handle.
 package Mail::DKIM::Verifier;
 use base "Mail::DKIM::Common";
 use Carp;
-our $VERSION = 0.38;
+our $VERSION = 0.41;
+our $MAX_SIGNATURES_TO_PROCESS = 50;
 
 sub init
 {
@@ -157,7 +158,6 @@ sub handle_header
 		{
 			my $signature = Mail::DKIM::Signature->parse($line);
 			$self->add_signature($signature);
-			$signature->fetch_public_key;
 		};
 		if ($@)
 		{
@@ -177,7 +177,6 @@ sub handle_header
 		{
 			my $signature = Mail::DKIM::DkSignature->parse($line);
 			$self->add_signature($signature);
-			$signature->fetch_public_key;
 		};
 		if ($@)
 		{
@@ -198,6 +197,10 @@ sub add_signature
 	croak "wrong number of arguments" unless (@_ == 1);
 	my ($signature) = @_;
 
+	# ignore signature headers once we've seen 50 or so
+	# this protects against abuse.
+	return if (@{$self->{signatures}} > $MAX_SIGNATURES_TO_PROCESS);
+
 	push @{$self->{signatures}}, $signature;
 
 	unless ($self->check_signature($signature))
@@ -207,6 +210,9 @@ sub add_signature
 		return;
 	}
 
+	# signature looks ok, go ahead and query for the public key
+	$signature->fetch_public_key;
+
 	# create a canonicalization filter and algorithm
 	my $algorithm_class = $signature->get_algorithm_class(
 				$signature->algorithm);
@@ -291,16 +297,21 @@ sub check_signature
 		return 0;
 	}
 
-	unless ($signature->domain ne '')
+	unless (defined $signature->domain)
 	{
 		# no domain specified
-		$self->{signature_reject_reason} =
-			!defined($signature->domain) ? "missing d tag"
-			: "invalid domain in d tag";
+		$self->{signature_reject_reason} = "missing d tag";
 		return 0;
 	}
 
-	unless ($signature->selector)
+	if ($signature->domain eq '')
+	{
+		# blank domain
+		$self->{signature_reject_reason} = "invalid domain in d tag";
+		return 0;
+	}
+
+	unless (defined $signature->selector)
 	{
 		# no selector specified
 		$self->{signature_reject_reason} = "missing s tag";
@@ -393,22 +404,7 @@ sub finish_header
 
 	foreach my $algorithm (@{$self->{algorithms}})
 	{
-		$algorithm->finish_header;
-	}
-
-	# For each parsed signature, check it for validity. If none are valid,
-	# our result is "invalid" and our result detail will be the reason
-	# why the last signature was invalid.
-
-	foreach my $signature (@{$self->{signatures}})
-	{
-		unless (check_signature_identity($signature))
-		{
-			$self->{signature_reject_reason} = "bad identity";
-			$signature->result("invalid",
-				$self->{signature_reject_reason});
-			next;
-		}
+		$algorithm->finish_header(Headers => $self->{headers});
 	}
 
 	# stop processing signatures that are already known to be invalid
@@ -421,8 +417,8 @@ sub finish_header
 	if (@{$self->{algorithms}} == 0
 		&& @{$self->{signatures}} > 0)
 	{
-		$self->{result} = $self->{signatures}->[0]->result;
-		$self->{details} = $self->{signatures}->[0]->{verify_details};
+		$self->{result} = $self->{signatures}->[0]->result || "invalid";
+		$self->{details} = $self->{signatures}->[0]->{verify_details} || $self->{signature_reject_reason};
 		return;
 	}
 }
@@ -434,6 +430,12 @@ sub _check_and_verify_signature
 
 		# check signature
 		my $signature = $algorithm->signature;
+		unless (check_signature_identity($signature))
+		{
+			$self->{signature_reject_reason} = "bad identity";
+			return ("invalid", $self->{signature_reject_reason});
+		}
+
 		# get public key
 		my $pkey;
 		eval
